pub trait HasStatement<'q> {
type Database: Database;
type Statement: Statement<'q, Database = Self::Database>;
}Expand description
Associate Database with a Statement of a generic lifetime.
The upcoming Rust feature, Generic Associated Types, should obviate the need for this trait.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".